<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: Hrvatski [HR]
Version: 2.3.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=422
Author: Piwigo team
Author URI: http://piwigo.org
*/

// Langage informations
$lang_info['language_name'] = 'Hrvatski';
$lang_info['country'] = 'Hrvatska';
$lang_info['direction'] = 'ltr';
$lang_info['code'] = 'hr';
$lang_info['zero_plural'] = true;

$lang['%d Kb'] = '%d Kb';
$lang['%d album updated'] = '%d skupina obnovljena';
$lang['%d albums updated'] = '%d skupine obnovljene';
$lang['%d comment to validate'] = '%d komentar za ovjeru';
$lang['%d comments to validate'] = '%d komentari za ovjeru';
$lang['%d new comment'] = '%d novi komentar';
$lang['%d new comments'] = '%d novi komentari';
$lang['%d comment'] = '%d komentar';
$lang['%d comments'] = '%d komentari';
$lang['%d hit'] = '%d posjet';
$lang['%d hits'] = '%d posjeta';
$lang['%d new photo'] = '%d nova slika';
$lang['%d new photos'] = '%d nove slike';
$lang['%d new user'] = '%d novi korisnik';
$lang['%d new users'] = '%d novi korisnici';
$lang['About'] = 'O...';
$lang['All tags'] = 'Svi tagovi';
$lang['Any tag'] = 'Bilo koji tag';
$lang['At least one listed rule must be satisfied.'] = 'Najmanje jedno od navedenih pravila mora biti zadovoljeno.';
$lang['At least one tag must match'] = 'Najmanje jedan tag se mora poklapati';
$lang['Author'] = 'Autor';
$lang['Albums'] = 'Skupine';
$lang['Album'] = 'Skupina';
$lang['Close this window'] = 'Zatvori prozor';
$lang['Complete RSS feed (photos, comments)'] = 'Potpuni RSS izvori (slike, komentari)';
$lang['Confirm Password'] = 'Potvrdi Zaporku';
$lang['Connection settings'] = 'Postavke povezivanja';
$lang['Login'] = 'Prijava';
$lang['Contact webmaster'] = 'Pišite webmaster-u';
$lang['Create a new account'] = 'Izradi novi račun';
$lang['Created on'] = 'Izrađen na';
$lang['Creation date'] = 'Nadnevak izrade';
$lang['Current password is wrong'] = 'Trenutna zaporka je neispravna';
$lang['Dimensions'] = 'Veličine';
$lang['Display'] = 'Prikaz';
$lang['Each listed rule must be satisfied.'] = 'Svako navedeno pravilo mora biti zadovoljeno.';
$lang['Email address is missing. Please specify an email address.'] = 'Nedostaje E-mail adresa';
$lang['Email address'] = 'E-mail adresa';
$lang['Enter your personnal informations'] = 'Upišite svoje osobne podatke';
$lang['Error sending email'] = 'Greška prilikom slanja e-mail poruke';
$lang['File name'] = 'Naziv zapisa';
$lang['File'] = 'Zapis';
$lang['Filesize'] = 'Veličina zapisa';
$lang['Filter and display'] = 'Filter i prikaz';
$lang['Filter'] = 'Filter';
$lang['Forgot your password?'] = 'Zaboravili ste zaporku?';
$lang['Go through the gallery as a visitor'] = 'Pregledajte galeriju kao posjetitelj';
$lang['Help'] = 'Pomoć';
$lang['Identification'] = 'Prijavnica';
$lang['Photos only RSS feed'] = 'RSS izvor samo za slike';
$lang['Keyword'] = 'Ključna riječ';
$lang['Links'] = 'Poveznice';
$lang['N/A'] = 'N/D';
$lang['New on %s'] = 'Novi na on %s';
$lang['New password confirmation does not correspond'] = 'Potvrda nove zaporke ne odgovara';
$lang['Notification'] = 'Obavijest';
$lang['Number of items'] = 'Broj stavki';
$lang['Original dimensions'] = 'Izvorne veličine';
$lang['Password forgotten'] = 'Zaboravljena zaporka';
$lang['Password'] = 'Zaporka';
$lang['Post date'] = 'Nadnevak objave';
$lang['Posted on'] = 'Objavljeno u';
$lang['Profile'] = 'Profil';
$lang['Quick connect'] = 'Brza veza';
$lang['RSS feed'] = 'RSS izvor';
$lang['Register'] = 'Upišite se';
$lang['Registration'] = 'Upis';
$lang['Related tags'] = 'Odnosni tagovi';
$lang['Reset'] = 'Poništi';
$lang['Retrieve password'] = 'Dohvati zaporku';
$lang['Search rules'] = 'Pravila pretrage';
$lang['Search tags'] = 'Tagovi pretrage';
$lang['Search'] = 'Pretraživanje';
$lang['display available tags'] = 'Pogledaj dostupne tagove';
$lang['Since'] = 'Od';
$lang['Sort by'] = 'Složeno po';
$lang['Sort order'] = 'Redoslijed slaganja';
$lang['Tag'] = 'Tag';
$lang['Tags'] = 'Tagovi';
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'RSS obavijesni izvor omogućava obavještavanje o novostima sa ovog web mjesta : nove slike, obnovljene skupine, nove komentare. Koristite čitač RSS izvora.';
$lang['Unknown feed identifier'] = 'Nepoznata oznaka izvora';
$lang['User comments'] = 'Korisnički komentari';
$lang['Username'] = 'Korisničko ime';
$lang['Visits'] = 'Posjeta';
$lang['Webmaster'] = 'Webmaster';
$lang['Week %d'] = 'Tjedan %d';
$lang['About Piwigo'] = 'O Piwigo-u';
$lang['You are not authorized to access the requested page'] = 'Niste ovlašteni za pristup zatraženoj stranici';
$lang['add to caddie'] = 'dodaj u ladicu';
$lang['add this photo to your favorites'] = 'dodaj ovu sliku u omiljene';
$lang['Administration'] = 'Uprava';
$lang['all'] = 'sve';
$lang['ascending'] = 'uzlazno';
$lang['author(s) : %s'] = 'autor(i) : %s';
$lang['Expand all albums'] = 'Proširi sve skupine';
$lang['posted after %s (%s)'] = 'objavljeno nakon %s (%s)';
$lang['posted before %s (%s)'] = 'objavljeno prije %s (%s)';
$lang['posted between %s (%s) and %s (%s)'] = 'objavljeno između %s (%s) i %s (%s)';
$lang['posted on %s'] = 'objavljeno na %s';
$lang['Best rated'] = 'Najbolje ocijenjeno';
$lang['display best rated photos'] = 'prikaz najbolje ocijenjenih stavki';
$lang['caddie'] = 'ladica';
$lang['Calendar'] = 'Kalendar';
$lang['All'] = 'Sve';
$lang['display each day with photos, month per month'] = 'prikaz svakog dana sa slikama, mjesec po mjesec';
$lang['View'] = 'Pogledaj';
$lang['chronology_monthly_calendar'] = 'Mjesečni kalendar';
$lang['chronology_monthly_list'] = 'Mjesečni popis';
$lang['chronology_weekly_list'] = 'Tjedni popis';
$lang['Click here if your browser does not automatically forward you'] = 'Kliknite ovdje ako niste samostalno prebačeni';
$lang['comment date'] = 'nadnevak komentara';
$lang['Comment'] = 'Komentar';
$lang['Your comment has been registered'] = 'Vaš je komentar upisan';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Anti-flood sustav : molimo sačekajte malo prije objave novog komentara';
$lang['Your comment has NOT been registered because it did not pass the validation rules'] = 'Vaš komentar NIJE upisan jer nije prošao pravila ovjere';
$lang['An administrator must authorize your comment before it is visible.'] = 'Upravnik mora odobriti vaš komentar prije objave.';
$lang['This login is already used by another user'] = 'Ovo korisničko ime se već koristi';
$lang['Comments'] = 'Komentari';
$lang['Add a comment'] = 'Dodaj komentar';
$lang['created after %s (%s)'] = 'izrađen nakon %s (%s)';
$lang['created before %s (%s)'] = 'izrađen prije %s (%s)';
$lang['created between %s (%s) and %s (%s)'] = 'izrađen između %s (%s) i %s (%s)';
$lang['created on %s'] = 'izrađen na %s';
$lang['Customize'] = 'Prilagodi';
$lang['Your Gallery Customization'] = 'Prilagodba Vaše Galerije ';
$lang['day'][0] = 'Nedjelja';
$lang['day'][1] = 'Ponedjeljak';
$lang['day'][2] = 'Utorak';
$lang['day'][3] = 'Srijeda';
$lang['day'][4] = 'Četvrtak';
$lang['day'][5] = 'Petak';
$lang['day'][6] = 'Subota';
$lang['Default'] = 'Pretpostavljeno';
$lang['delete this photo from your favorites'] = 'uklonite ovu sliku iz omiljenih';
$lang['Delete'] = 'Ukloni';
$lang['descending'] = 'silazno';
$lang['download'] = 'preuzmi';
$lang['download this file'] = 'preuzmi ovaj zapis';
$lang['edit'] = 'uredi';
$lang['wrong date'] = 'krivi nadnevak';
$lang['excluded'] = 'isključeno';
$lang['Your favorites'] = 'Moji omiljeni';
$lang['display your favorites photos'] = 'prikaz mojih omiljenih slika';
$lang['Favorites'] = 'Omiljeni';
$lang['First'] = 'Prvi';
$lang['The gallery is locked for maintenance. Please, come back later.'] = 'Galerija je zaključana zbog održavanja. Molimo, navratite kasnije.';
$lang['Page generated in'] = 'Stranica izrađena u ';
$lang['guest'] = 'gost';
$lang['Hello'] = 'Pozdrav';
$lang['available for administrators only'] = 'dostupno samo upraviteljima';
$lang['display this album'] = 'prikazuje slike u korijenu skupine';
$lang['display last user comments'] = 'Pregled zadnjih korisničkih komentara';
$lang['customize the appareance of the gallery'] = 'prilagodite izgled vaše galerije';
$lang['search'] = 'pretraži';
$lang['Home'] = 'Naslovnica';
$lang['in this album'] = 'u ovoj skupini';
$lang['in %d sub-album'] = 'u %d podskupini';
$lang['in %d sub-albums'] = 'u %d podskupinama';
$lang['included'] = 'uključeno';
$lang['Invalid password!'] = 'Nevaljana zaporka!';
$lang['Language']='Jezik';
$lang['last %d days'] = 'zadnjih %d dana';
$lang['Last'] = 'Zadnji';
$lang['Logout'] = 'Odjava';
$lang['E-mail address'] = 'E-mail adresa';
$lang['obligatory'] = 'obvezno';
$lang['Maximum photo height'] = 'Najveća dozvoljena visina slika';
$lang['Maximum height must be a number superior to 50'] = 'Najveća visina mora biti broj veći od 50';
$lang['Maximum photo width'] = 'Najveća dozvoljena širina slika';
$lang['Maximum width must be a number superior to 50'] = 'Najveća širina mora biti broj veći od 50';
$lang['display a calendar by creation date'] = 'prikaz kalendara po nadnevku izrade';
$lang['display all photos in all sub-albums'] = 'prikaz svih stavki u svim podskupinama';
$lang['return to normal view mode'] = 'povratak u uobičajeni način pregleda';
$lang['display a calendar by posted date'] = 'prikaz kalendara po nadnevku objave';
$lang['month'][10] = 'Listopad';
$lang['month'][11] = 'Studeni';
$lang['month'][12] = 'Prosinac';
$lang['month'][1] = 'Siječanj';
$lang['month'][2] = 'Veljača';
$lang['month'][3] = 'Ožujak';
$lang['month'][4] = 'Travanj';
$lang['month'][5] = 'Svibanj';
$lang['month'][6] = 'Lipanj';
$lang['month'][7] = 'Srpanj';
$lang['month'][8] = 'Kolovoz';
$lang['month'][9] = 'Rujan';
$lang['Most visited'] = 'Najposjećenije';
$lang['display most visited photos'] = 'prikaz najposjećenijih slika';
$lang['The number of photos per page must be a not null scalar'] = 'broj slika po stranici mora biti cjelobrojna vrijednost';
$lang['Number of photos per page'] = 'Broj slika po stranici';
$lang['Unknown identifier'] = 'Nepoznata oznaka';
$lang['New password'] = 'Nova zaporka';
$lang['Rate this photo'] = 'Ocjeni ovu sliku';
$lang['Next'] = 'Slijedeći';
$lang['no rate'] = 'bez ocjene';
$lang['Photos posted within the last %d day.'] = 'Stavke objavljene u zadnjem %d danu.';
$lang['Photos posted within the last %d days.'] = 'Stavke objavljene između zadnjih %d dana.';
$lang['password updated'] = 'zaporka obnovljena';
$lang['Recent period must be a positive integer value'] = 'Nedavno razdoblje mora biti pozitivna cjelobrojna vrijednost';
/* DEPRECATED USED IN comments.php FOR image_id ? */ $lang['photo'] = 'slika';
$lang['Click on the photo to see it in high definition'] = 'Klikni na sliku za pregled u visokoj razlučljivosti';
$lang['Show file metadata'] = 'Prikaži meta podatke zapisa';
$lang['Powered by'] = 'Osnaženo sa';
$lang['Preferences'] = 'Postavke';
$lang['Previous'] = 'Prethodni';
$lang['Random photos'] = 'Slike slučajnog odabira';
$lang['display a set of random photos'] = 'prikaz slika slučajnim odabirom';
$lang['Recent albums'] = 'Nedavne skupine';
$lang['display recently updated albums'] = 'prikaz nedavno obnovljenih skupina';
$lang['Recent period'] = 'Nedavno razdoblje';
$lang['Recent photos'] = 'Nedavne slike';
$lang['display most recent photos'] = 'prikaz najnovijih slika';
$lang['Redirection...'] = 'Preusmjeravanje...';
$lang['Please, enter a login'] = 'Molimo, prijavite se';
$lang['login mustn\'t end with a space character'] = 'prijava ne smije završavati razmakom';
$lang['login mustn\'t start with a space character'] = 'prijava ne smije počinjati razmakom';
$lang['this login is already used'] = 'ovo korisničko ime se već koristi';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'e-mail adresa mora biti oblika xxx@yyy.eee (npr : pasko@stranica.org)';
$lang['please enter your password again'] = 'molimo unesite zaporku ponovo';
$lang['Auto login'] = 'Samoprijava';
$lang['remove this tag from the list'] = 'ukloni  ovaj tag iz popisa';
$lang['representative'] = 'predstavnik';
$lang['Search for Author'] = 'Pretraživanje po Autoru';
$lang['Search in albums'] = 'Pretraživanje u Skupinama';
$lang['Search by Date'] = 'Pretraživanje po Nadnevku';
$lang['Date'] = 'Nadnevak';
$lang['End-Date'] = 'Krajnji Nadnevak';
$lang['Kind of date'] = 'Vrsta nadnevka';
$lang['Search for words'] = 'Pretraživanje po riječima';
$lang['Search for all terms'] = 'Pretraživanje po svim uvjetima ';
$lang['Search for any terms'] = 'Pretraživanje po bilo kojem uvjetu';
$lang['Empty query. No criteria has been entered.'] = 'Prazni upit. Nije uneseno ni jedno obilježje.';
$lang['Search Options'] = 'Mogućnosti Pretraživanja';
$lang['Search results'] = 'Ishodi pretraživanja';
$lang['Search in sub-albums'] = 'Pretraga u podskupinama';
$lang['searched words : %s'] = 'tražene riječi : %s';
$lang['Contact'] = 'Kontakt';
$lang['set as album representative'] = 'postavi za predstavnika skupine';
$lang['Show number of comments'] = 'Prikaži broj komentara';
$lang['Show number of hits'] = 'Prikaži broj posjeta';
$lang['slideshow'] = 'klizni prikaz';
$lang['stop the slideshow'] = 'zaustavi klizni prikaz';
$lang['Specials'] = 'Posebnosti';
$lang['SQL queries in'] = 'SQL upita u ';
$lang['display only recently posted photos'] = 'prikaz samo nedavno objavljenih slika';
$lang['return to the display of all photos'] = 'povratak u prikaz svih slika';
$lang['the beginning'] = 'početak';
$lang['Interface theme'] = 'tema sučelja';
$lang['Thumbnails'] = 'Povezne sličice';
$lang['Menu'] = 'Izbornik';
$lang['A comment on your site'] = 'Komentar na vašem web mjestu';
$lang['today'] = 'danas';
$lang['Update your rating'] = 'Obnovite svoju ocjenu';
$lang['wrong filename'] = 'krivi naziv zapisa';
$lang['the username must be given'] = 'mora se upisati korisničko ime';
$lang['useful when password forgotten'] = 'korisno kada se zaboravi zaporka';
$lang['Quick search'] = 'Brzo pretraživanje';
$lang['Connected user: %s'] = 'Spojeni korisnik: %s';
$lang['IP: %s'] = 'IP: %s';
$lang['Browser: %s'] = 'Preglednik: %s';
$lang['Author: %s'] = 'Autor: %s';
$lang['Comment: %s'] = 'Komentar: %s';
$lang['Comment by %s'] = 'Komentirao-la %s';
$lang['User: %s'] = 'Korisnik: %s';
$lang['Email: %s'] = 'E-mail: %s';
$lang['Admin: %s'] = 'Upravitelj: %s';
$lang['Registration of %s'] = 'Upis od %s';
$lang['Album: %s'] = 'Skupina: %s';
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Loš status za korisnika "guest", koristi se pretpostavljeni status. Molimo obavjestite webmaster-a.';
$lang['this email address is already in use'] = 'korisnik već koristi ovu e-mail adresu';
$lang['Album results for'] = 'Ishodi skupine za ';
$lang['Tag results for'] = 'Ishodi tagova za';
$lang['from %s to %s'] = 'od %s do %s';
$lang['Play of slideshow'] = 'Pokreni klizni prikaz';
$lang['Pause of slideshow'] = 'Zaustavi klizni prikaz';
$lang['Repeat the slideshow'] = 'Ponovi klizni prikaz';
$lang['Not repeat the slideshow'] = 'Ne ponavljaj klizni prikaz';
$lang['Reduce diaporama speed'] = 'Smanji brzinu diaporama-e';
$lang['Accelerate diaporama speed'] = 'Povećaj brzinu diaporama-e';
$lang['Submit'] = 'Pošalji';
$lang['Yes'] = 'Da';
$lang['No'] = 'Ne';
$lang['%d photo']='%d slika';
$lang['%d photos']='%d slike';
$lang['%d photo is also linked to current tags'] = '%d slika također povezana sa trenutnim tagovima';
$lang['%d photos are also linked to current tags'] = '%d slike također povezana sa trenutnim tagovima';
$lang['display photos linked to this tag'] = 'Pregledaj slike povezane samo sa ovim tag-om';
$lang['photos posted during the last %d days'] = 'slike objavljene tijekon zadnjih %d dana';
$lang['Piwigo Help'] = 'Piwigo Pomoć';
$lang['Rank'] = 'Redoslijed';
$lang['group by letters'] = 'složeno po slovima';
$lang['letters'] = 'slova';
$lang['show tag cloud'] = 'prikaži tag oblak';
$lang['cloud'] = 'oblak';
$lang['Are you sure?'] = 'Sigurni ste?';
$lang['delete this comment'] = 'izbriši ovaj komentar';
$lang['Reset to default values'] = 'Povratak na pretpostavljene vrijednosti';
$lang['delete all photos from your favorites'] = 'izbriši sve slike iz omiljenih';
$lang['Sent by'] = 'Poslano od';
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = 'Kolačići su onemogućeni ili nisu podržani od vašeg preglednika. Morate ih omogućiti za prijavu.';
$lang['edit this comment'] = 'uredi ovaj komentar';
$lang['Edit a comment'] = 'Uredi komentar';
$lang['(!) This comment requires validation'] = '(!) Ovaj komentar zahtijeva ovjeru';
$lang['Welcome'] = 'Dobrodošli';
$lang['Welcome to your Piwigo photo gallery!'] = 'Dobrodošli u vašu Piwigo galeriju slika!';
$lang['... or browse your empty gallery'] = '... ili pregledajte praznu galeriju';
$lang['... or please deactivate this message, I will find my way by myself'] = '... ili možete isključiti ovu poruku, nekako ću se snaći sam';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = 'Zdravo %s, vaša Piwigo galerija je prazna!';
$lang['I want to add photos'] = 'Želim dodati slike';
$lang['Manage this user comment: %s'] = 'Upravljanje ovim korisničkim komentarom: %s';
$lang['This author modified following comment:'] = 'Ovaj autor je promijenio slijedeći komentar:';
$lang['This author removed the comment with id %d'] = 'Ovaj autor je uklonio komentar sa id %d';
$lang['validate this comment'] = 'ovjeri ovaj komentar';
$lang['html tags are not allowed in login'] = 'u korisničkim podacima nisu dozvoljene html oznake';
$lang['%d rates'] = '%d ocjena';
$lang['Rating score'] = 'Rezultat ocjenjivanja';
$lang['Enter a username or email address'] = 'Unesite korisničko ime ili email adresu';
$lang['Invalid username or email'] = 'Korisničko ime ili email nisu valjani';
$lang['Password reset is not allowed for this user'] = 'Ovom korisniku nije dozvoljeno ponovno postavljanje lozinke';
$lang['User "%s" has no email address, password reset is not possible'] = 'Korisnik "%s" nema email adresu, ponovno postavljanje lozinke nije moguće';
$lang['Someone requested that the password be reset for the following user account:'] = 'Netko je zatražio ponovno postavljanje zaboravljene lozinke za korisnički račun:';
$lang['Username "%s" on gallery %s'] = 'Korisničko ime "%s" na galeriji %s';
$lang['To reset your password, visit the following address:'] = 'Za izmjenu zaboravljene lozinke posjetite:';
$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Ukoliko ste greškom dobili ovu poruku slobodno je zanemarite i ništa se neće desiti.';
$lang['Password Reset'] = 'Zaboravili ste lozinku?';
$lang['Check your email for the confirmation link'] = 'Provjerite svoj email, naći ćete link za potvrdu.';
$lang['Invalid key'] = 'Ključ nije valjan';
$lang['The passwords do not match'] = 'Lozinke se ne podudaraju';
$lang['Your password has been reset'] = 'Lozinka vam je izmijenjena';
$lang['Return to home page'] = 'Povratak na početnu stranicu';
$lang['Please enter your username or email address.'] = 'Molimo vas da unesete vaše korisničko ime ili email adresu.';
$lang['You will receive a link to create a new password via email.'] = 'Link za izmjenu lozinke poslan vam je u email poruci.';
$lang['Username or email'] = 'Korisničko ime ili lozinka';
$lang['Change my password'] = 'Promjena lozinke';
$lang['Enter your new password below.'] = 'Unesite vašu novu lozinku.';
$lang['Reset Password'] = 'Promjeni lozinku.';
$lang['EXIF Metadata'] = 'EXIF metapodaci';
$lang['IPTC Metadata'] = 'IPTC metapodaci';

?>